import os
import re
from pathlib import Path

def extract_frontmatter(content):
    """Extract and process frontmatter from MDX files"""
    frontmatter_match = re.match(r'---\s*(.*?)\s*---', content, re.DOTALL)
    
    if frontmatter_match:
        # Extract frontmatter content
        frontmatter = frontmatter_match.group(1)
        # Extract main content (everything after frontmatter)
        main_content = content[frontmatter_match.end():].strip()
        return frontmatter, main_content
    
    return None, content  # No frontmatter found

def process_mdx_file(file_path):
    """Process a single MDX file and return its plain text content with context header"""
    try:
        with open(file_path, 'r', encoding='utf-8') as file:
            content = file.read()
            
        # Extract frontmatter and main content
        frontmatter, main_content = extract_frontmatter(content)
        
        # Get relative path for context
        relative_path = os.path.relpath(file_path, os.path.join('src', 'content', 'docs'))
        dir_path = os.path.dirname(relative_path)
        file_name = os.path.basename(file_path)
        
        # Prepare the header with minimal context
        formatted_content = f"# {file_name}\n"
        
        # Add title from frontmatter if exists
        if frontmatter:
            title_match = re.search(r'title:\s*[\'"]?(.*?)[\'"]?($|\n)', frontmatter, re.MULTILINE)
            if title_match:
                title = title_match.group(1)
                formatted_content = f"# {title}\n"
        
        # Clean up the main content
        # Remove import statements
        main_content = re.sub(r'import.*?;?\n', '', main_content)
        
        # Remove JSX/MDX components
        main_content = re.sub(r'<[^>]*>', '', main_content)
        
        # Remove license text and common headers/footers
        main_content = re.sub(r'(Copyright.*?reserved\..*?\n)', '', main_content, flags=re.IGNORECASE | re.DOTALL)
        main_content = re.sub(r'(Licensed under.*?\..*?\n)', '', main_content, flags=re.IGNORECASE | re.DOTALL)
        
        # Remove markdown code blocks with language specifiers
        main_content = re.sub(r'```[a-z]*\n', '```\n', main_content)
        
        # Remove extraneous blank lines
        main_content = re.sub(r'\n{3,}', '\n\n', main_content)
        
        # Add the cleaned content
        formatted_content += f"\nPath: {dir_path}\n\n" + main_content.strip() + "\n\n---\n\n"
        
        return formatted_content
    except Exception as e:
        return f"## Error processing {file_path}\n\nError: {str(e)}\n\n---\n\n"

def consolidate_docs(repo_path='cloudflare-docs', output_dir='../output'):
    """
    Consolidate all MDX files in the docs directory into separate MD files by section.
    Plain text extraction: removes MDX formatting, components, license headers, and other non-content elements.
    
    Args:
        repo_path: Path to the repository root
        output_dir: Directory to output the consolidated MD files
    """
    # Create full paths
    docs_path = os.path.join(repo_path, 'src', 'content', 'docs')
    output_path = os.path.join(repo_path, output_dir)
    
    # Ensure output directory exists
    os.makedirs(output_path, exist_ok=True)
    
    # Dictionary to store content for each section
    sections = {}
    
    # Walk through all directories and files
    for root, dirs, files in os.walk(docs_path):
        for file in files:
            if file.endswith('.mdx'):
                file_path = os.path.join(root, file)
                
                # Get the top-level section name
                rel_path = os.path.relpath(file_path, docs_path)
                section = rel_path.split(os.sep)[0]
                
                content = process_mdx_file(file_path)
                
                # Add to the section's content
                if section not in sections:
                    sections[section] = []
                sections[section].append(content)
    
    # Write consolidated content to output files
    for section, contents in sections.items():
        output_file = os.path.join(output_path, f"{section}.md")
        
        with open(output_file, 'w', encoding='utf-8') as f:
            f.write(f"# {section.upper()} Documentation\n\n")
            f.write("\n".join(contents))
        
        print(f"Created {output_file} with {len(contents)} MDX files consolidated")

if __name__ == "__main__":
    consolidate_docs()
    print("Documentation consolidation complete!")